<div align="center">
  <img src="https://raw.githubusercontent.com/DirksCGM/DBtoS3/master/static/logo.png"><br>
</div>

Replication & Full Load Application for multiple databases to s3

[![PyPI](https://img.shields.io/pypi/v/dbtos3)](https://pypi.org/project/dbtos3/)
[![DeepSource](https://static.deepsource.io/deepsource-badge-light-mini.svg)](https://deepsource.io/gh/DirksCGM/DBtoS3/?ref=repository-badge)
[![Dependabot](https://badgen.net/dependabot/thepracticaldev/dev.to?icon=dependabot)](https://app.dependabot.com/accounts/DirksCGM/repos/266711720)
[![Perceptech Data Software Foundation](https://raw.githubusercontent.com/DirksCGM/DBtoS3/master/static/icon.png)](https://perceptechdata.com/perceptech-data-software-foundation/)

## How to use

Please make use of the [Wiki](https://github.com/DirksCGM/DBtoS3/wiki) which will be updated continuously with information.

## Current features

### Databases
* [PostgreSQL to S3 - full load and replication](https://github.com/DirksCGM/DBtoS3/wiki/PostgreSQL)
* [MySQL to S3 - full load and replication](https://github.com/DirksCGM/DBtoS3/wiki/MySQL)

### Applications
* [Sentry to S3 - full load and replication](https://github.com/DirksCGM/DBtoS3/wiki/Sentry)
    * organization projects
    * organisation project events
    
*More will be added over time*

## Development
This project is developed and maintained by the [Perceptech Data Software Foundation](https://perceptechdata.com/perceptech-data-software-foundation/)
[![pdsf](https://github.com/DirksCGM/DBtoS3/wiki/static/PDSF.png)](https://perceptechdata.com/perceptech-data-software-foundation/)
